Class: IonoscloudDbaasPostgres::BackupsApi
- Inherits:
-
Object
- Object
- IonoscloudDbaasPostgres::BackupsApi
- Defined in:
- lib/ionoscloud-dbaas-postgres/api/backups_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cluster_backups_get(cluster_id, opts = {}) ⇒ ClusterBackupList
List backups of cluster Retrieves a list of all backups of the given PostgreSQL cluster.
-
#cluster_backups_get_with_http_info(cluster_id, opts = {}) ⇒ Array<(ClusterBackupList, Integer, Hash)>
List backups of cluster Retrieves a list of all backups of the given PostgreSQL cluster.
-
#clusters_backups_find_by_id(backup_id, opts = {}) ⇒ BackupResponse
Fetch a cluster backup Retrieve a PostgreSQL cluster backup by using its ID.
-
#clusters_backups_find_by_id_with_http_info(backup_id, opts = {}) ⇒ Array<(BackupResponse, Integer, Hash)>
Fetch a cluster backup Retrieve a PostgreSQL cluster backup by using its ID.
-
#clusters_backups_get(opts = {}) ⇒ ClusterBackupList
List cluster backups Retrieves a list of all PostgreSQL cluster backups.
-
#clusters_backups_get_with_http_info(opts = {}) ⇒ Array<(ClusterBackupList, Integer, Hash)>
List cluster backups Retrieves a list of all PostgreSQL cluster backups.
-
#initialize(api_client = ApiClient.default) ⇒ BackupsApi
constructor
A new instance of BackupsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BackupsApi
Returns a new instance of BackupsApi.
19 20 21 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cluster_backups_get(cluster_id, opts = {}) ⇒ ClusterBackupList
List backups of cluster Retrieves a list of all backups of the given PostgreSQL cluster.
27 28 29 30 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 27 def cluster_backups_get(cluster_id, opts = {}) data, _status_code, _headers = cluster_backups_get_with_http_info(cluster_id, opts) data end |
#cluster_backups_get_with_http_info(cluster_id, opts = {}) ⇒ Array<(ClusterBackupList, Integer, Hash)>
List backups of cluster Retrieves a list of all backups of the given PostgreSQL cluster.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 37 def cluster_backups_get_with_http_info(cluster_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BackupsApi.cluster_backups_get ...' end # verify the required parameter 'cluster_id' is set if @api_client.config.client_side_validation && cluster_id.nil? fail ArgumentError, "Missing the required parameter 'cluster_id' when calling BackupsApi.cluster_backups_get" end # resource path local_var_path = '/clusters/{clusterId}/backups'.sub('{' + 'clusterId' + '}', CGI.escape(cluster_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClusterBackupList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'tokenAuth'] = opts.merge( :operation => :"BackupsApi.cluster_backups_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BackupsApi#cluster_backups_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#clusters_backups_find_by_id(backup_id, opts = {}) ⇒ BackupResponse
Fetch a cluster backup Retrieve a PostgreSQL cluster backup by using its ID. This value can be found when you GET a list of PostgreSQL cluster backups.
90 91 92 93 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 90 def clusters_backups_find_by_id(backup_id, opts = {}) data, _status_code, _headers = clusters_backups_find_by_id_with_http_info(backup_id, opts) data end |
#clusters_backups_find_by_id_with_http_info(backup_id, opts = {}) ⇒ Array<(BackupResponse, Integer, Hash)>
Fetch a cluster backup Retrieve a PostgreSQL cluster backup by using its ID. This value can be found when you GET a list of PostgreSQL cluster backups.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 100 def clusters_backups_find_by_id_with_http_info(backup_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BackupsApi.clusters_backups_find_by_id ...' end # verify the required parameter 'backup_id' is set if @api_client.config.client_side_validation && backup_id.nil? fail ArgumentError, "Missing the required parameter 'backup_id' when calling BackupsApi.clusters_backups_find_by_id" end # resource path local_var_path = '/clusters/backups/{backupId}'.sub('{' + 'backupId' + '}', CGI.escape(backup_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BackupResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'tokenAuth'] = opts.merge( :operation => :"BackupsApi.clusters_backups_find_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BackupsApi#clusters_backups_find_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#clusters_backups_get(opts = {}) ⇒ ClusterBackupList
List cluster backups Retrieves a list of all PostgreSQL cluster backups.
152 153 154 155 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 152 def clusters_backups_get(opts = {}) data, _status_code, _headers = clusters_backups_get_with_http_info(opts) data end |
#clusters_backups_get_with_http_info(opts = {}) ⇒ Array<(ClusterBackupList, Integer, Hash)>
List cluster backups Retrieves a list of all PostgreSQL cluster backups.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/ionoscloud-dbaas-postgres/api/backups_api.rb', line 161 def clusters_backups_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BackupsApi.clusters_backups_get ...' end # resource path local_var_path = '/clusters/backups' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClusterBackupList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'tokenAuth'] = opts.merge( :operation => :"BackupsApi.clusters_backups_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BackupsApi#clusters_backups_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |