Class: IonoscloudDbaasPostgres::ClusterBackupList

Inherits:
Object
  • Object
show all
Defined in:
lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb

Overview

List of backups.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClusterBackupList

Initializes the object



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IonoscloudDbaasPostgres::ClusterBackupList` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IonoscloudDbaasPostgres::ClusterBackupList`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }
  

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end


  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end


  if attributes.key?(:'items') && (value = attributes[:'items']).is_a?(Array)
    self.items = value
  end


  if attributes.key?(:'offset')
    self.offset = attributes[:'offset']
  end


  if attributes.key?(:'limit')
    self.limit = attributes[:'limit']
  end


  if attributes.key?(:'_links')
    self._links = attributes[:'_links']
  end
end

Instance Attribute Details

Returns the value of attribute _links.



38
39
40
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 38

def _links
  @_links
end

#idObject

The unique ID of the resource.



24
25
26
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 24

def id
  @id
end

#itemsObject

Returns the value of attribute items.



27
28
29
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 27

def items
  @items
end

#limitObject

The limit specified in the request (if none was specified, use the endpoint’s default pagination limit) (not implemented yet, always return number of items).



35
36
37
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 35

def limit
  @limit
end

#offsetObject

The offset specified in the request (if none was specified, the default offset is 0) (not implemented yet).



31
32
33
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 31

def offset
  @offset
end

#typeObject

Returns the value of attribute type.



20
21
22
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 59

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 41

def self.attribute_map
  {
    
    :'type' => :'type',

    :'id' => :'id',

    :'items' => :'items',

    :'offset' => :'offset',

    :'limit' => :'limit',

    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



236
237
238
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 236

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



94
95
96
97
98
99
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 94

def self.openapi_all_of
  [
  :'ClusterBackupListAllOf',
  :'Pagination'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
88
89
90
91
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 82

def self.openapi_nullable
  Set.new([
    





  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 64

def self.openapi_types
  {
    
    :'type' => :'ResourceType',

    :'id' => :'String',

    :'items' => :'Array<BackupResponse>',

    :'offset' => :'Integer',

    :'limit' => :'Integer',

    :'_links' => :'PaginationLinks'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



210
211
212
213
214
215
216
217
218
219
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
    type == o.type &&
    id == o.id &&
    items == o.items &&
    offset == o.offset &&
    limit == o.limit &&
    _links == o._links
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 266

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IonoscloudDbaasPostgres.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 337

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 243

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


223
224
225
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



229
230
231
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 229

def hash
  [type, id, items, offset, limit, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 149

def list_invalid_properties
  invalid_properties = Array.new
  



  if !@offset.nil? && @offset < 0
    invalid_properties.push('invalid value for "offset", must be greater than or equal to 0.')
  end


  if !@limit.nil? && @limit < 0
    invalid_properties.push('invalid value for "limit", must be greater than or equal to 0.')
  end


  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



313
314
315
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 313

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 319

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



307
308
309
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 307

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



170
171
172
173
174
175
176
177
178
179
180
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_backup_list.rb', line 170

def valid?
  



  return false if !@offset.nil? && @offset < 0

  return false if !@limit.nil? && @limit < 0

  true
end