Class: IonoscloudDbaasPostgres::ClusterProperties

Inherits:
Object
  • Object
show all
Defined in:
lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb

Overview

Properties of a database cluster

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClusterProperties

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IonoscloudDbaasPostgres::ClusterProperties` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IonoscloudDbaasPostgres::ClusterProperties`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'postgres_version')
    self.postgres_version = attributes[:'postgres_version']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'backup_location')
    self.backup_location = attributes[:'backup_location']
  end

  if attributes.key?(:'instances')
    self.instances = attributes[:'instances']
  end

  if attributes.key?(:'ram')
    self.ram = attributes[:'ram']
  end

  if attributes.key?(:'cores')
    self.cores = attributes[:'cores']
  end

  if attributes.key?(:'storage_size')
    self.storage_size = attributes[:'storage_size']
  end

  if attributes.key?(:'storage_type')
    self.storage_type = attributes[:'storage_type']
  end

  if attributes.key?(:'connections') && (value = attributes[:'connections']).is_a?(Array)
    self.connections = value
  end

  if attributes.key?(:'maintenance_window')
    self.maintenance_window = attributes[:'maintenance_window']
  end

  if attributes.key?(:'synchronization_mode')
    self.synchronization_mode = attributes[:'synchronization_mode']
  end
end

Instance Attribute Details

#backup_locationObject

The S3 location where the backups will be stored.



29
30
31
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 29

def backup_location
  @backup_location
end

#connectionsObject

Returns the value of attribute connections.



45
46
47
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 45

def connections
  @connections
end

#coresObject

The number of CPU cores per instance.



38
39
40
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 38

def cores
  @cores
end

#display_nameObject

The friendly name of your cluster.



20
21
22
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 20

def display_name
  @display_name
end

#instancesObject

The total number of instances in the cluster (one master and n-1 standbys).



32
33
34
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 32

def instances
  @instances
end

#locationObject

The physical location where the cluster will be created. This will be where all of your instances live. Property cannot be modified after datacenter creation.



26
27
28
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 26

def location
  @location
end

#maintenance_windowObject

Returns the value of attribute maintenance_window.



47
48
49
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 47

def maintenance_window
  @maintenance_window
end

#postgres_versionObject

The PostgreSQL version of your cluster.



23
24
25
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 23

def postgres_version
  @postgres_version
end

#ramObject

The amount of memory per instance in megabytes. Has to be a multiple of 1024.



35
36
37
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 35

def ram
  @ram
end

#storage_sizeObject

The amount of storage per instance in megabytes.



41
42
43
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 41

def storage_size
  @storage_size
end

#storage_typeObject

Returns the value of attribute storage_type.



43
44
45
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 43

def storage_type
  @storage_type
end

#synchronization_modeObject

Returns the value of attribute synchronization_mode.



49
50
51
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 49

def synchronization_mode
  @synchronization_mode
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 70

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 52

def self.attribute_map
  {
    :'display_name' => :'displayName',
    :'postgres_version' => :'postgresVersion',
    :'location' => :'location',
    :'backup_location' => :'backupLocation',
    :'instances' => :'instances',
    :'ram' => :'ram',
    :'cores' => :'cores',
    :'storage_size' => :'storageSize',
    :'storage_type' => :'storageType',
    :'connections' => :'connections',
    :'maintenance_window' => :'maintenanceWindow',
    :'synchronization_mode' => :'synchronizationMode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 311

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 75

def self.openapi_types
  {
    :'display_name' => :'String',
    :'postgres_version' => :'String',
    :'location' => :'String',
    :'backup_location' => :'String',
    :'instances' => :'Integer',
    :'ram' => :'Integer',
    :'cores' => :'Integer',
    :'storage_size' => :'Integer',
    :'storage_type' => :'StorageType',
    :'connections' => :'Array<Connection>',
    :'maintenance_window' => :'MaintenanceWindow',
    :'synchronization_mode' => :'SynchronizationMode'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_name == o.display_name &&
      postgres_version == o.postgres_version &&
      location == o.location &&
      backup_location == o.backup_location &&
      instances == o.instances &&
      ram == o.ram &&
      cores == o.cores &&
      storage_size == o.storage_size &&
      storage_type == o.storage_type &&
      connections == o.connections &&
      maintenance_window == o.maintenance_window &&
      synchronization_mode == o.synchronization_mode
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 341

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = IonoscloudDbaasPostgres.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 412

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 318

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 304

def hash
  [display_name, postgres_version, location, backup_location, instances, ram, cores, storage_size, storage_type, connections, maintenance_window, synchronization_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 164

def list_invalid_properties
  invalid_properties = Array.new
  if !@instances.nil? && @instances > 5
    invalid_properties.push('invalid value for "instances", must be smaller than or equal to 5.')
  end

  if !@instances.nil? && @instances < 1
    invalid_properties.push('invalid value for "instances", must be greater than or equal to 1.')
  end

  if !@ram.nil? && @ram < 2048
    invalid_properties.push('invalid value for "ram", must be greater than or equal to 2048.')
  end

  if !@cores.nil? && @cores < 1
    invalid_properties.push('invalid value for "cores", must be greater than or equal to 1.')
  end

  if !@storage_size.nil? && @storage_size > 2097152
    invalid_properties.push('invalid value for "storage_size", must be smaller than or equal to 2097152.')
  end

  if !@storage_size.nil? && @storage_size < 2048
    invalid_properties.push('invalid value for "storage_size", must be greater than or equal to 2048.')
  end

  if !@connections.nil? && @connections.length > 1
    invalid_properties.push('invalid value for "connections", number of items must be less than or equal to 1.')
  end

  if !@connections.nil? && @connections.length < 1
    invalid_properties.push('invalid value for "connections", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



388
389
390
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 388

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 394

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



382
383
384
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 382

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
213
# File 'lib/ionoscloud-dbaas-postgres/models/cluster_properties.rb', line 203

def valid?
  return false if !@instances.nil? && @instances > 5
  return false if !@instances.nil? && @instances < 1
  return false if !@ram.nil? && @ram < 2048
  return false if !@cores.nil? && @cores < 1
  return false if !@storage_size.nil? && @storage_size > 2097152
  return false if !@storage_size.nil? && @storage_size < 2048
  return false if !@connections.nil? && @connections.length > 1
  return false if !@connections.nil? && @connections.length < 1
  true
end