Class: IonoscloudDbaasPostgres::MetadataApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ionoscloud-dbaas-postgres/api/metadata_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ MetadataApi



19
20
21
# File 'lib/ionoscloud-dbaas-postgres/api/metadata_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ionoscloud-dbaas-postgres/api/metadata_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#infos_version_get(opts = {}) ⇒ APIVersion

Get the current API version Retrieves the current version of the responding API.



26
27
28
29
# File 'lib/ionoscloud-dbaas-postgres/api/metadata_api.rb', line 26

def infos_version_get(opts = {})
  data, _status_code, _headers = infos_version_get_with_http_info(opts)
  data
end

#infos_version_get_with_http_info(opts = {}) ⇒ Array<(APIVersion, Integer, Hash)>

Get the current API version Retrieves the current version of the responding API.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/ionoscloud-dbaas-postgres/api/metadata_api.rb', line 35

def infos_version_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MetadataApi.infos_version_get ...'
  end
  # resource path
  local_var_path = '/infos/version'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'APIVersion'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'tokenAuth']

  new_options = opts.merge(
    :operation => :"MetadataApi.infos_version_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MetadataApi#infos_version_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#infos_versions_get(opts = {}) ⇒ Array<APIVersion>

Fetch all API versions Retrieves all available versions of the responding API.



83
84
85
86
# File 'lib/ionoscloud-dbaas-postgres/api/metadata_api.rb', line 83

def infos_versions_get(opts = {})
  data, _status_code, _headers = infos_versions_get_with_http_info(opts)
  data
end

#infos_versions_get_with_http_info(opts = {}) ⇒ Array<(Array<APIVersion>, Integer, Hash)>

Fetch all API versions Retrieves all available versions of the responding API.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/ionoscloud-dbaas-postgres/api/metadata_api.rb', line 92

def infos_versions_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MetadataApi.infos_versions_get ...'
  end
  # resource path
  local_var_path = '/infos/versions'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<APIVersion>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'tokenAuth']

  new_options = opts.merge(
    :operation => :"MetadataApi.infos_versions_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MetadataApi#infos_versions_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end